<?php

namespace Drupal\grequest\Entity\Form;

use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\grequest\Plugin\GroupContentEnabler\GroupMembershipRequest;

/**
 * Provides a form for approving a group membership request.
 */
class GroupMembershipApproveForm extends ContentEntityConfirmFormBase {

  /**
   * Returns the plugin responsible for this piece of group content.
   *
   * @return \Drupal\group\Plugin\GroupContentEnablerInterface
   *   The responsible group content enabler plugin.
   */
  protected function getContentPlugin() {
    return $this->getEntity()->getContentPlugin();
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to approve this request?');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return $this->getEntity()->getGroup()->toUrl();
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Approve');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $group_content = $this->getEntity();

    $group_content
      ->set('grequest_status', GroupMembershipRequest::REQUEST_APPROVED)
      // Who created request will become an 'approver' for Membership request.
      ->set('grequest_updated_by', $this->currentUser()->id());
    $result = $group_content->save();

    if ($result) {
      $this->messenger()->addStatus($this->t('Membership request approved'));

      // Adding user to a group.
      $group_content->getGroup()->addMember($group_content->getEntity());
    }
    else {
      $this->messenger()->addError($this->t('Error updating request'));
    }

    \Drupal::logger('group_content')->notice('@type: approved %title.', [
      '@type' => $group_content->bundle(),
      '%title' => $group_content->label(),
    ]);

    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
